aboutsummaryrefslogtreecommitdiffstats
path: root/src/passphrase.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/passphrase.h')
-rw-r--r--src/passphrase.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/passphrase.h b/src/passphrase.h
index 9a1baa5..2114fbe 100644
--- a/src/passphrase.h
+++ b/src/passphrase.h
@@ -25,17 +25,17 @@
*
* @return The passphrase, should be wiped `free`:ed, `NULL` on error
*/
-extern char* get_passphrase(void);
+extern char* passphrase_read(void);
/**
* Disable echoing and do anything else to the terminal settnings `get_passphrase` requires
*/
-extern void disable_echo(void);
+extern void passphrase_disable_echo(void);
/**
* Undo the actions of `disable_echo`
*/
-extern void reenable_echo(void);
+extern void passphrase_reenable_echo(void);
#endif
@@ -25,17 +25,17 @@
/**
- * Disable echoing and do anything else to the terminal settnings `get_passphrase` requires
+ * Disable echoing and do anything else to the terminal settnings `passphrase_read` requires
*/
@@ -25,17 +25,17 @@
/**
- * Undo the actions of `disable_echo`
+ * Undo the actions of `passphrase_disable_echo`
*/